@@ -10,11 +10,13 @@
 #' returns just taxon name, key, latitude, and longitute. Or specify each field
 #' you want returned by name, e.g. fields = c('name','latitude','elevation').
 #' @param return One of 'data', 'hier', 'meta', or 'all'. If 'data', a
-#'   data.frame with the data. 'hier' returns the classifications in a list for
-#'   each record. 'meta' returns the metadata for the entire call. 'all'
-#'   (default) gives all data back in a list.
+#' data.frame with the data. 'hier' returns the classifications in a list for
+#' each record. 'meta' returns the metadata for the entire call. 'all'
+#' (default) gives all data back in a list.
 #' @param ... additional facet parameters
 #' @seealso [downloads()], [occ_data()], [occ_facet()]
+#' @note Maximum number of records you can get with this function is 100,000.
+#' See https://www.gbif.org/developer/occurrence
 #' @return An object of class `gbif`, which is a S3 class list, with
 #' slots for metadata (`meta`), the occurrence data itself (`data`),
 #' the taxonomic hierarchy data (`hier`), and media metadata
@@ -34,7 +36,8 @@ occ_search <- function(taxonKey=NULL, scientificName=NULL, country=NULL,
   publishingCountry=NULL, hasCoordinate=NULL, typeStatus=NULL,
   recordNumber=NULL, lastInterpreted=NULL, continent=NULL, geometry=NULL,
   geom_big="asis",
-  geom_size=40, geom_n=10, recordedBy=NULL, basisOfRecord=NULL, datasetKey=NULL,
+  geom_size=40, geom_n=10, recordedBy=NULL, recordedByID=NULL,
+  identifiedByID=NULL, basisOfRecord=NULL, datasetKey=NULL,
   eventDate=NULL, catalogNumber=NULL, year=NULL, month=NULL,
   decimalLatitude=NULL,
   decimalLongitude=NULL, elevation=NULL, depth=NULL, institutionCode=NULL,
@@ -81,7 +84,8 @@ occ_search <- function(taxonKey=NULL, scientificName=NULL, country=NULL,
       convmany(taxonKey), convmany(scientificName), convmany(country),
       convmany(publishingCountry), convmany(datasetKey),
       convmany(typeStatus), convmany(recordNumber), convmany(continent),
-      convmany(recordedBy), convmany(catalogNumber), convmany(institutionCode),
+      convmany(recordedBy), convmany(recordedByID), convmany(identifiedByID),
+      convmany(catalogNumber), convmany(institutionCode),
       convmany(collectionCode), convmany(geometry), convmany(mediaType),
       convmany(subgenusKey), convmany(phylumKey), convmany(kingdomKey),
       convmany(classKey), convmany(orderKey), convmany(familyKey),
@@ -186,7 +190,8 @@ occ_search <- function(taxonKey=NULL, scientificName=NULL, country=NULL,
   params <- list(
     taxonKey=taxonKey,scientificName=scientificName,datasetKey=datasetKey,
     catalogNumber=catalogNumber,
-    recordedBy=recordedBy,geometry=geometry,country=country,
+    recordedBy=recordedBy,recordedByID=recordedByID, identifiedByID=identifiedByID,
+    geometry=geometry, country=country,
     publishingCountry=publishingCountry,recordNumber=recordNumber,
     q=search,institutionCode=institutionCode,collectionCode=collectionCode,
     continent=continent,
@@ -254,8 +259,9 @@ check_limit <- function(x){
 }
 
 possparams <- function(){
-  "taxonKey, scientificName, datasetKey, catalogNumber, recordedBy, geometry,
-  country, publishingCountry, recordNumber, search, institutionCode,
-  collectionCode, decimalLatitude, decimalLongitude, depth, year, typeStatus,
-  lastInterpreted, continent, or mediatype"
+  "taxonKey, scientificName, datasetKey, catalogNumber, recordedBy,
+  recordedByID, identifiedByID, geometry, country, publishingCountry,
+  recordNumber, search, institutionCode, collectionCode, decimalLatitude,
+  decimalLongitude, depth, year, typeStatus, lastInterpreted,
+  continent, or mediatype"
 }
